==> haskell-test-framework-0.8.2.0-329-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework
version:              0.8.2.0
visibility:           public
id:                   test-framework-0.8.2.0-GByTqDthQwE1lawuzEXBOt
key:                  test-framework-0.8.2.0-GByTqDthQwE1lawuzEXBOt
license:              BSD-3-Clause
maintainer:           Libraries List <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             http://haskell.github.io/test-framework/
synopsis:
    Framework for running and organising tests, with HUnit and QuickCheck support

description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.

category:             Testing
abi:                  15d8bdb2727de60cf21b992335f1b7f2
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.API Test.Framework.Runners.Console
    Test.Framework.Runners.Options Test.Framework.Runners.TestPattern
    Test.Framework.Seed

hidden-modules:
    Test.Framework.Core Test.Framework.Improving
    Test.Framework.Runners.Console.Colors
    Test.Framework.Runners.Console.ProgressBar
    Test.Framework.Runners.Console.Run
    Test.Framework.Runners.Console.Statistics
    Test.Framework.Runners.Console.Table
    Test.Framework.Runners.Console.Utilities
    Test.Framework.Runners.Core Test.Framework.Runners.Processors
    Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
    Test.Framework.Runners.TimedConsumption
    Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
    Test.Framework.Utilities

import-dirs:          /usr/lib/ghc-9.0.1/site-local/test-framework-0.8.2.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/test-framework-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/test-framework-0.8.2.0
hs-libraries:         HStest-framework-0.8.2.0-GByTqDthQwE1lawuzEXBOt
depends:
    ansi-terminal-0.11-C9raGJmrRpQ318ixPrYCyd
    ansi-wl-pprint-0.6.9-5kAefjUZBm91H5yPXTcmwO base-4.15.0.0
    containers-0.6.4.1 hostname-1.0-Br1jPZ1TQM2JEvPBDCu2td
    old-locale-1.0.0.7-8b6vATcbl2rGNT5WzdAV1N
    random-1.2.0-74k23DwBCPn1Xv1wOi89IV
    regex-posix-0.96.0.1-ICff79JbeoKL4XN6EAg8yK time-1.9.3
    xml-1.3.14-21i4vhiJSXU6kuSJCTj4ZG

haddock-interfaces:
    /usr/share/doc/haskell-test-framework/html/test-framework.haddock

haddock-html:         /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-0.8.2.0-332-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework
version:              0.8.2.0
visibility:           public
id:                   test-framework-0.8.2.0-DUvbcPHKHkgBFjCiG52NEt
key:                  test-framework-0.8.2.0-DUvbcPHKHkgBFjCiG52NEt
license:              BSD-3-Clause
maintainer:           Libraries List <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             http://haskell.github.io/test-framework/
synopsis:
    Framework for running and organising tests, with HUnit and QuickCheck support

description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.

category:             Testing
abi:                  1b63462aa34b3b0427136d29cdab8bc8
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.API Test.Framework.Runners.Console
    Test.Framework.Runners.Options Test.Framework.Runners.TestPattern
    Test.Framework.Seed

hidden-modules:
    Test.Framework.Core Test.Framework.Improving
    Test.Framework.Runners.Console.Colors
    Test.Framework.Runners.Console.ProgressBar
    Test.Framework.Runners.Console.Run
    Test.Framework.Runners.Console.Statistics
    Test.Framework.Runners.Console.Table
    Test.Framework.Runners.Console.Utilities
    Test.Framework.Runners.Core Test.Framework.Runners.Processors
    Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
    Test.Framework.Runners.TimedConsumption
    Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
    Test.Framework.Utilities

import-dirs:          /usr/lib/ghc-9.0.1/site-local/test-framework-0.8.2.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/test-framework-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/test-framework-0.8.2.0
hs-libraries:         HStest-framework-0.8.2.0-DUvbcPHKHkgBFjCiG52NEt
depends:
    ansi-terminal-0.11-FDn5stAeTja6b4Fn65mtJG
    ansi-wl-pprint-0.6.9-95vZwYgp3dpIWorR2M49WC base-4.15.0.0
    containers-0.6.4.1 hostname-1.0-Br1jPZ1TQM2JEvPBDCu2td
    old-locale-1.0.0.7-8b6vATcbl2rGNT5WzdAV1N
    random-1.2.0-1BE3Y1nCod49ZuCEOwydFE
    regex-posix-0.96.0.1-ICff79JbeoKL4XN6EAg8yK time-1.9.3
    xml-1.3.14-21i4vhiJSXU6kuSJCTj4ZG

haddock-interfaces:
    /usr/share/doc/haskell-test-framework/html/test-framework.haddock

haddock-html:         /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
